HumanDetectionException class

Exception thrown when human detection operations fail.

Implemented types

Constructors

HumanDetectionException(String message, {String? code, dynamic details})
Creates a new HumanDetectionException.
const
HumanDetectionException.fromPlatformException(dynamic e)
Creates a HumanDetectionException from a platform exception.
factory

Properties

code String?
Error code for programmatic handling.
final
details → dynamic
Additional details about the error.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Error message describing what went wrong.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited