HumanDetectionPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • HumanDetectionPlatform
Implementers

Constructors

HumanDetectionPlatform()
Constructs a HumanDetectionPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

detectHuman(String imagePath) Future<HumanDetectionResult>
Detect human in image at the given path.
detectHumanFromBytes(Uint8List imageBytes) Future<HumanDetectionResult>
Detect human from image bytes.
dispose() Future<void>
Dispose of resources.
getPlatformVersion() Future<String?>
Get platform version.
initialize(HumanDetectionOptions options) Future<void>
Initialize the human detection model.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance HumanDetectionPlatform
The default instance of HumanDetectionPlatform to use.
getter/setter pair