MethodChannelHumanDetection class
An implementation of HumanDetectionPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- HumanDetectionPlatform
- MethodChannelHumanDetection
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
detectHuman(
String imagePath) → Future< HumanDetectionResult> -
Detect human in image at the given path.
override
-
detectHumanFromBytes(
Uint8List imageBytes) → Future< HumanDetectionResult> -
Detect human from image bytes.
override
-
dispose(
) → Future< void> -
Dispose of resources.
override
-
getPlatformVersion(
) → Future< String?> -
Get platform version.
override
-
initialize(
HumanDetectionOptions options) → Future< void> -
Initialize the human detection model.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited